ModelDescriptor class
- Annotations
Constructors
Properties
- description → String?
-
final
- displayName → String
-
final
- downloadSizeBytes → int
-
final
- downloadSizeLabel → String
-
Human-readable download size
no setter
- downloadUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isAvailable → bool
-
Whether this model is ready to use (bundled or already downloaded)
no setter
- isDetector → bool
-
True when this descriptor advertises itself as an object-detection
model (e.g. NudeNet) via
metadata["kind"] == "detector". Defaults to false so classifier models keep working unchanged.no setter - isDownloaded → bool
-
final
-
metadata
→ Map<
String, dynamic> -
final
- requiresDownload → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override