PermissionStatus enum
Aggregate permission status the widget renders.
Maps from the existing PhotoLibraryPermissionStatus (gallery scan) and the future camera-permission status (Phase 2 / 3 native handlers).
Values
- limited → const PermissionStatus
- denied → const PermissionStatus
- permanentlyDenied → const PermissionStatus
- restricted → const PermissionStatus
- notDetermined → const PermissionStatus
Properties
- canRequest → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGranted → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - needsSettings → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String? s) → PermissionStatus
Constants
-
values
→ const List<
PermissionStatus> - A constant List of the values in this enum, in order of their declaration.