NsfwPlatformInterface class abstract
- Inheritance
-
- Object
- PlatformInterface
- NsfwPlatformInterface
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanEventStream
→ Stream<
Map> -
no setter
Methods
-
availableModels(
) → Future< List< ModelDescriptor> > -
cancelScan(
) → Future< void> -
checkPermission(
) → Future< PhotoLibraryPermissionStatus> -
deleteModel(
String modelId) → Future< void> -
downloadModel(
String modelId, {String? url}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preloadModel(
String modelId) → Future< void> -
requestPermission(
) → Future< PhotoLibraryPermissionStatus> -
resetScan(
) → Future< void> -
scanFilePath(
String filePath, {String? modelId}) → Future< Map> -
scanImageBytes(
Uint8List bytes, {String? modelId}) → Future< Map> -
scanSingleAsset(
String localIdentifier, {String? modelId}) → Future< Map> -
setLogging(
bool enabled) → Future< void> -
setModelUrl(
String modelId, String url) → Future< void> -
startPickAndScan(
ScanConfiguration config, int maxItems) → Future< void> -
startScan(
ScanConfiguration config) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ NsfwPlatformInterface
-
getter/setter pair